#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-hslua
version:              1.1.1.1
visibility:           public
id:                   tasty-hslua-1.1.1.1-AHxQUx9Qg2W3AwDhdSoLDP
key:                  tasty-hslua-1.1.1.1-AHxQUx9Qg2W3AwDhdSoLDP
license:              MIT
copyright:            © 2017-2026 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Tasty helpers to test HsLua.
description:
    Various tasty helpers and utilities to test HsLua
    oparations. Built on top of tasty-hunit.

category:             Foreign
abi:                  7662818d280222f5da7eabc17a1e0e48
exposed:              True
exposed-modules:      Test.Tasty.HsLua
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-hslua-1.1.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-hslua-1.1.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-hslua-1.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hslua
hs-libraries:         HStasty-hslua-1.1.1.1-AHxQUx9Qg2W3AwDhdSoLDP
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    hslua-core-2.3.2-ABXu6faa3PJ6iIiStpPDNc
    tasty-1.5.2-DzOELAxGOkcCrvV9YMidRG
    tasty-hunit-0.10.2-6ErY3WlEMWP2KrXMiwd0vI

haddock-interfaces:   /usr/share/doc/haskell-tasty-hslua/html/tasty-hslua.haddock
haddock-html:         /usr/share/doc/haskell-tasty-hslua/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

